@@ -468,17 +468,6 @@ parser_end_node_cb (GMarkupParseContext  *context,
 	}
 }
 
-static void
-parser_error_cb (GMarkupParseContext *context,
-		 GError              *error,
-		 gpointer             user_data)
-{
-	DhParser *parser = user_data;
-
-	g_markup_parse_context_free (parser->context);
- 	parser->context = NULL;
-}
-
 static gboolean
 parser_read_gz_file (DhParser     *parser,
                      const gchar  *path,
@@ -565,7 +554,6 @@ dh_parser_read_file (const gchar  *path,
 
 	parser->m_parser->start_element = parser_start_node_cb;
 	parser->m_parser->end_element = parser_end_node_cb;
-	parser->m_parser->error = parser_error_cb;
 
 	parser->context = g_markup_parse_context_new (parser->m_parser, 0,
 						      parser, NULL);
@@ -607,13 +595,17 @@ dh_parser_read_file (const gchar  *path,
                         if (io_status == G_IO_STATUS_EOF || io_status == G_IO_STATUS_ERROR) {
                                 break;
                         }
-                        g_markup_parse_context_parse (parser->context, buf,
-                                                      bytes_read, error);
-                        if (error != NULL && *error != NULL) {
+                        if (!g_markup_parse_context_parse (parser->context, buf,
+                                                           bytes_read, error)) {
                                 result = FALSE;
                                 goto exit;
                         }
                 }
+
+                if (!g_markup_parse_context_end_parse (parser->context, error)) {
+                        result = FALSE;
+                        goto exit;
+                }
         }
 
  exit:
